Predictions
===========

.. currentmodule:: pykeen.predict

.. autoclass:: Predictions
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Predictions.add_membership_columns
      ~Predictions.exchange_df
      ~Predictions.filter_triples

   .. rubric:: Methods Documentation

   .. automethod:: add_membership_columns
   .. automethod:: exchange_df
   .. automethod:: filter_triples
